@@ -1,6 +1,6 @@
 #' A precise & pristine [ggplot2] theme with opinionated defaults and an emphasis on typoghraphy
 #'
-#' You should [import_plex_sans()] first and also install the fonts on your
+#' You should [import_plex_sans()] first and install the fonts on your
 #' system before trying to use this theme.
 #'
 #' There is an option `hrbrthemes.loadfonts` which -- if set to `TRUE` -- will
@@ -21,7 +21,7 @@
 #' @param strip_text_family,strip_text_face,strip_text_size facet label font family, face and size
 #' @param caption_family,caption_face,caption_size,caption_margin plot caption family, face, size and margin
 #' @param axis_title_family,axis_title_face,axis_title_size axis title font family, face and size
-#' @param axis_title_just axis title font justificationk one of `[blmcrt]`
+#' @param axis_title_just axis title font justification one of `[blmcrt]`
 #' @param axis_text_size font size of axis text
 #' @param plot_margin plot margin (specify with [ggplot2::margin])
 #' @param grid_col grid color
@@ -37,7 +37,7 @@
 #' # seminal scatterplot
 #' ggplot(mtcars, aes(mpg, wt)) +
 #'   geom_point() +
-#'   labs(x="Fuel effiiency (mpg)", y="Weight (tons)",
+#'   labs(x="Fuel efficiency (mpg)", y="Weight (tons)",
 #'        title="Seminal ggplot2 scatterplot example",
 #'        subtitle="A plot that is only useful for demonstration purposes",
 #'        caption="Brought to you by the letter 'g'") +
@@ -52,7 +52,7 @@
 #'   ggplot(aes(class, n)) +
 #'   geom_col() +
 #'   geom_text(aes(label=n), nudge_y=3) +
-#'   labs(x="Fuel effiiency (mpg)", y="Weight (tons)",
+#'   labs(x="Fuel efficiency (mpg)", y="Weight (tons)",
 #'        title="Seminal ggplot2 bar chart example",
 #'        subtitle="A plot that is only useful for demonstration purposes",
 #'        caption="Brought to you by the letter 'g'") +
@@ -87,9 +87,9 @@ theme_ipsum_ps <- function(
 
   if (inherits(grid, "character") | grid == TRUE) {
 
-    ret <- ret + theme(panel.grid=element_line(color=grid_col, size=0.2))
-    ret <- ret + theme(panel.grid.major=element_line(color=grid_col, size=0.2))
-    ret <- ret + theme(panel.grid.minor=element_line(color=grid_col, size=0.15))
+    ret <- ret + theme(panel.grid=element_line(color=grid_col, linewidth=0.2))
+    ret <- ret + theme(panel.grid.major=element_line(color=grid_col, linewidth=0.2))
+    ret <- ret + theme(panel.grid.minor=element_line(color=grid_col, linewidth=0.15))
 
     if (inherits(grid, "character")) {
       if (regexpr("X", grid)[1] < 0) ret <- ret + theme(panel.grid.major.x=element_blank())
@@ -103,22 +103,22 @@ theme_ipsum_ps <- function(
   }
 
   if (inherits(axis, "character") | axis == TRUE) {
-    ret <- ret + theme(axis.line=element_line(color=axis_col, size=0.15))
+    ret <- ret + theme(axis.line=element_line(color=axis_col, linewidth=0.15))
     if (inherits(axis, "character")) {
       axis <- tolower(axis)
       if (regexpr("x", axis)[1] < 0) {
         ret <- ret + theme(axis.line.x=element_blank())
       } else {
-        ret <- ret + theme(axis.line.x=element_line(color=axis_col, size=0.15))
+        ret <- ret + theme(axis.line.x=element_line(color=axis_col, linewidth=0.15))
       }
       if (regexpr("y", axis)[1] < 0) {
         ret <- ret + theme(axis.line.y=element_blank())
       } else {
-        ret <- ret + theme(axis.line.y=element_line(color=axis_col, size=0.15))
+        ret <- ret + theme(axis.line.y=element_line(color=axis_col, linewidth=0.15))
       }
     } else {
-      ret <- ret + theme(axis.line.x=element_line(color=axis_col, size=0.15))
-      ret <- ret + theme(axis.line.y=element_line(color=axis_col, size=0.15))
+      ret <- ret + theme(axis.line.x=element_line(color=axis_col, linewidth=0.15))
+      ret <- ret + theme(axis.line.y=element_line(color=axis_col, linewidth=0.15))
     }
   } else {
     ret <- ret + theme(axis.line=element_blank())
@@ -129,9 +129,9 @@ theme_ipsum_ps <- function(
     ret <- ret + theme(axis.ticks.x = element_blank())
     ret <- ret + theme(axis.ticks.y = element_blank())
   } else {
-    ret <- ret + theme(axis.ticks = element_line(size=0.15))
-    ret <- ret + theme(axis.ticks.x = element_line(size=0.15))
-    ret <- ret + theme(axis.ticks.y = element_line(size=0.15))
+    ret <- ret + theme(axis.ticks = element_line(linewidth=0.15))
+    ret <- ret + theme(axis.ticks.x = element_line(linewidth=0.15))
+    ret <- ret + theme(axis.ticks.y = element_line(linewidth=0.15))
     ret <- ret + theme(axis.ticks.length = grid::unit(5, "pt"))
   }
 
@@ -175,21 +175,12 @@ theme_ipsum_ps <- function(
 #' to register non-core fonts with the Windows graphics device.
 #'
 #' @md
-#' @note This will take care of ensuring PDF/PostScript usage. The location of the
-#'   font directory is displayed after the base import is complete. It is highly
-#'   recommended that you install them on your system the same way you would any
-#'   other font you wish to use in other programs.
 #' @export
 import_plex_sans <- function() {
 
-  ps_font_dir <- system.file("fonts", "plex-sans", package="hrbrthemes")
-
-  suppressWarnings(suppressMessages(extrafont::font_import(ps_font_dir, prompt=FALSE)))
-
   message(
-    sprintf(
-      "You will likely need to install these fonts on your system as well.\n\nYou can find them in [%s]",
-      ps_font_dir)
+    "You can find IBM Plex Sans at https://github.com/IBM/plex. Please install them ",
+    "and run extrafont::font_import()"
   )
 
 }
